package com.sygem.swing.demos;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import com.sygem.swing.colorchooser.AdvancedColorChooser;
import com.sygem.swing.colorchooser.CustomColorDataSource;
import java.util.Random;

/**
 * <p>Title: AdvancedColorChooser</p>
 * <p>Description: A sophisticated Color Chooser dialog</p>
 * <p>Copyright: Copyright (c) 2004</p>
 * <p>Company: SyGem Software</p>
 * @author Simon Jewell
 * @version 1.0
 */

public class ColorChooserDemoFrame extends JFrame {
  JPanel contentPane;
  BorderLayout borderLayout1 = new BorderLayout();
  JButton colorChooserButton = new JButton();

  //Construct the frame
  public ColorChooserDemoFrame() {
    enableEvents(AWTEvent.WINDOW_EVENT_MASK);
    try {
      jbInit();
    }
    catch(Exception e) {
      e.printStackTrace();
    }
  }

  //Component initialization
  private void jbInit() throws Exception  {
    contentPane = (JPanel) this.getContentPane();

    AdvancedColorChooser.registerCustomColorDataSource(new CustomColorDataSource() {

      Random r = new Random(System.currentTimeMillis());

      public Color getColor(int i) {
        Color c = new Color(r.nextInt(255),r.nextInt(255),r.nextInt(255));
        return c;
      }
      public void setColor(int i,Color c) {
        System.out.println("setting custom color "+i+" to "+c);
      }
    });

    colorChooserButton.setText("Click to change TEXT color");
    colorChooserButton.addActionListener(new ColorChooserDemoFrame_colorChooserButton_actionAdapter(this));
    contentPane.setLayout(borderLayout1);
    this.setSize(new Dimension(200, 75));
    this.setTitle("AdvancedColorChooser Simple Demo");
    contentPane.add(colorChooserButton, BorderLayout.CENTER);
  }

  //Overridden so we can exit when window is closed
  protected void processWindowEvent(WindowEvent e) {
    super.processWindowEvent(e);
    if (e.getID() == WindowEvent.WINDOW_CLOSING) {
      System.exit(0);
    }
  }

  void colorChooserButton_actionPerformed(ActionEvent e) {
    colorChooserButton.setForeground(AdvancedColorChooser.showDialog(this,"Choose a color",colorChooserButton.getForeground()));
  }
}

class ColorChooserDemoFrame_colorChooserButton_actionAdapter implements java.awt.event.ActionListener {
  ColorChooserDemoFrame adaptee;

  ColorChooserDemoFrame_colorChooserButton_actionAdapter(ColorChooserDemoFrame adaptee) {
    this.adaptee = adaptee;
  }
  public void actionPerformed(ActionEvent e) {
    adaptee.colorChooserButton_actionPerformed(e);
  }
}
